@@ -33,25 +33,28 @@ RSpec.describe "bundle gem" do
   let(:minitest_test_class_name) { "class TestMygem < Minitest::Test" }
 
   before do
-    sys_exec("git config --global user.name 'Bundler User'")
-    sys_exec("git config --global user.email user@example.com")
-    sys_exec("git config --global github.user bundleuser")
+    git("config --global user.name 'Bundler User'")
+    git("config --global user.email user@example.com")
+    git("config --global github.user bundleuser")
+
+    global_config "BUNDLE_GEM__MIT" => "false", "BUNDLE_GEM__TEST" => "false", "BUNDLE_GEM__COC" => "false", "BUNDLE_GEM__LINTER" => "false",
+                  "BUNDLE_GEM__CI" => "false", "BUNDLE_GEM__CHANGELOG" => "false"
   end
 
   describe "git repo initialization" do
-    it "generates a gem skeleton with a .git folder", :readline do
+    it "generates a gem skeleton with a .git folder" do
       bundle "gem #{gem_name}"
       gem_skeleton_assertions
       expect(bundled_app("#{gem_name}/.git")).to exist
     end
 
-    it "generates a gem skeleton with a .git folder when passing --git", :readline do
+    it "generates a gem skeleton with a .git folder when passing --git" do
       bundle "gem #{gem_name} --git"
       gem_skeleton_assertions
       expect(bundled_app("#{gem_name}/.git")).to exist
     end
 
-    it "generates a gem skeleton without a .git folder when passing --no-git", :readline do
+    it "generates a gem skeleton without a .git folder when passing --no-git" do
       bundle "gem #{gem_name} --no-git"
       gem_skeleton_assertions
       expect(bundled_app("#{gem_name}/.git")).not_to exist
@@ -62,7 +65,9 @@ RSpec.describe "bundle gem" do
         Dir.mkdir(bundled_app("path with spaces"))
       end
 
-      it "properly initializes git repo", :readline do
+      it "properly initializes git repo" do
+        skip "path with spaces needs special handling on Windows" if Gem.win_platform?
+
         bundle "gem #{gem_name}", dir: bundled_app("path with spaces")
         expect(bundled_app("path with spaces/#{gem_name}/.git")).to exist
       end
@@ -104,7 +109,7 @@ RSpec.describe "bundle gem" do
     end
 
     it "generates the README with a section for the Code of Conduct, respecting the configured git default branch", git: ">= 2.28.0" do
-      sys_exec("git config --global init.defaultBranch main")
+      git("config --global init.defaultBranch main")
       bundle "gem #{gem_name} --coc"
 
       expect(bundled_app("#{gem_name}/README.md").read).to include("## Code of Conduct")
@@ -131,7 +136,7 @@ RSpec.describe "bundle gem" do
     before do
       bundle "gem #{gem_name} --changelog"
     end
-    it "generates a gem skeleton with a CHANGELOG", :readline do
+    it "generates a gem skeleton with a CHANGELOG" do
       gem_skeleton_assertions
       expect(bundled_app("#{gem_name}/CHANGELOG.md")).to exist
     end
@@ -141,7 +146,7 @@ RSpec.describe "bundle gem" do
     before do
       bundle "gem #{gem_name} --no-changelog"
     end
-    it "generates a gem skeleton without a CHANGELOG", :readline do
+    it "generates a gem skeleton without a CHANGELOG" do
       gem_skeleton_assertions
       expect(bundled_app("#{gem_name}/CHANGELOG.md")).to_not exist
     end
@@ -150,6 +155,7 @@ RSpec.describe "bundle gem" do
   shared_examples_for "--rubocop flag" do
     context "is deprecated", bundler: "< 3" do
       before do
+        global_config "BUNDLE_GEM__LINTER" => nil
         bundle "gem #{gem_name} --rubocop"
       end
 
@@ -263,11 +269,11 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  shared_examples_for "--linter=none flag" do
+  shared_examples_for "--no-linter flag" do
     define_negated_matcher :exclude, :include
 
     before do
-      bundle "gem #{gem_name} --linter=none"
+      bundle "gem #{gem_name} --no-linter"
     end
 
     it "generates a gem skeleton without rubocop" do
@@ -303,49 +309,49 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  it "has no rubocop offenses when using --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     bundle "gem #{gem_name} --linter=rubocop"
     bundle_exec_rubocop
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=c and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=c and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     bundle "gem #{gem_name} --ext=c --linter=rubocop"
     bundle_exec_rubocop
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=c, --test=minitest, and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=c, --test=minitest, and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     bundle "gem #{gem_name} --ext=c --test=minitest --linter=rubocop"
     bundle_exec_rubocop
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=c, --test=rspec, and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=c, --test=rspec, and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     bundle "gem #{gem_name} --ext=c --test=rspec --linter=rubocop"
     bundle_exec_rubocop
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=c, --test=test-unit, and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=c, --test=test-unit, and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     bundle "gem #{gem_name} --ext=c --test=test-unit --linter=rubocop"
     bundle_exec_rubocop
     expect(last_command).to be_success
   end
 
-  it "has no standard offenses when using --linter=standard flag", :readline do
+  it "has no standard offenses when using --linter=standard flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     bundle "gem #{gem_name} --linter=standard"
     bundle_exec_standardrb
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=rust and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=rust and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     skip "RubyGems incompatible with Rust builder" if ::Gem::Version.new("3.3.11") > ::Gem.rubygems_version
 
@@ -354,7 +360,7 @@ RSpec.describe "bundle gem" do
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=rust, --test=minitest, and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=rust, --test=minitest, and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     skip "RubyGems incompatible with Rust builder" if ::Gem::Version.new("3.3.11") > ::Gem.rubygems_version
 
@@ -363,7 +369,7 @@ RSpec.describe "bundle gem" do
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=rust, --test=rspec, and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=rust, --test=rspec, and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     skip "RubyGems incompatible with Rust builder" if ::Gem::Version.new("3.3.11") > ::Gem.rubygems_version
 
@@ -372,7 +378,7 @@ RSpec.describe "bundle gem" do
     expect(last_command).to be_success
   end
 
-  it "has no rubocop offenses when using --ext=rust, --test=test-unit, and --linter=rubocop flag", :readline do
+  it "has no rubocop offenses when using --ext=rust, --test=test-unit, and --linter=rubocop flag" do
     skip "ruby_core has an 'ast.rb' file that gets in the middle and breaks this spec" if ruby_core?
     skip "RubyGems incompatible with Rust builder" if ::Gem::Version.new("3.3.11") > ::Gem.rubygems_version
 
@@ -399,7 +405,7 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  context "README.md", :readline do
+  context "README.md" do
     context "git config github.user present" do
       before do
         bundle "gem #{gem_name}"
@@ -413,7 +419,7 @@ RSpec.describe "bundle gem" do
 
     context "git config github.user is absent" do
       before do
-        sys_exec("git config --global --unset github.user")
+        git("config --global --unset github.user")
         bundle "gem #{gem_name}"
       end
 
@@ -422,14 +428,30 @@ RSpec.describe "bundle gem" do
         expect(bundled_app("#{gem_name}/README.md").read).not_to include("github.com/bundleuser")
       end
     end
+
+    describe "test task name on readme" do
+      shared_examples_for "test task name on readme" do |framework, task_name|
+        before do
+          bundle "gem #{gem_name} --test=#{framework}"
+        end
+
+        it "renders with correct name" do
+          expect(bundled_app("#{gem_name}/README.md").read).to include("Then, run `rake #{task_name}` to run the tests.")
+        end
+      end
+
+      it_behaves_like "test task name on readme", "test-unit", "test"
+      it_behaves_like "test task name on readme", "minitest", "test"
+      it_behaves_like "test task name on readme", "rspec", "spec"
+    end
   end
 
-  it "creates a new git repository", :readline do
+  it "creates a new git repository" do
     bundle "gem #{gem_name}"
     expect(bundled_app("#{gem_name}/.git")).to exist
   end
 
-  context "when git is not available", :readline do
+  context "when git is not available" do
     # This spec cannot have `git` available in the test env
     before do
       load_paths = [lib_dir, spec_dir]
@@ -451,20 +473,23 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  it "generates a valid gemspec", :readline, :ruby_repo do
+  it "generates a valid gemspec", :ruby_repo do
     bundle "gem newgem --bin"
 
     prepare_gemspec(bundled_app("newgem", "newgem.gemspec"))
 
-    gems = ["rake-#{rake_version}"]
+    build_repo2 do
+      build_dummy_irb "9.9.9"
+    end
+    gems = ["rake-#{rake_version}", "irb-9.9.9"]
     path = Bundler.feature_flag.default_install_uses_path? ? local_gem_path(base: bundled_app("newgem")) : system_gem_path
-    system_gems gems, path: path
+    system_gems gems, path: path, gem_repo: gem_repo2
     bundle "exec rake build", dir: bundled_app("newgem")
 
     expect(last_command.stdboth).not_to include("ERROR")
   end
 
-  context "gem naming with relative paths", :readline do
+  context "gem naming with relative paths" do
     it "resolves ." do
       create_temporary_dir("tmp")
 
@@ -557,8 +582,12 @@ RSpec.describe "bundle gem" do
 
       expect(bundled_app("#{gem_name}/bin/setup")).to exist
       expect(bundled_app("#{gem_name}/bin/console")).to exist
-      expect(bundled_app("#{gem_name}/bin/setup")).to be_executable
-      expect(bundled_app("#{gem_name}/bin/console")).to be_executable
+
+      unless Gem.win_platform?
+        expect(bundled_app("#{gem_name}/bin/setup")).to be_executable
+        expect(bundled_app("#{gem_name}/bin/console")).to be_executable
+      end
+
       expect(bundled_app("#{gem_name}/bin/setup").read).to start_with("#!")
       expect(bundled_app("#{gem_name}/bin/console").read).to start_with("#!")
     end
@@ -591,8 +620,8 @@ RSpec.describe "bundle gem" do
 
     context "git config user.{name,email} is not set" do
       before do
-        sys_exec("git config --global --unset user.name")
-        sys_exec("git config --global --unset user.email")
+        git("config --global --unset user.name")
+        git("config --global --unset user.email")
         bundle "gem #{gem_name}"
       end
 
@@ -671,6 +700,9 @@ RSpec.describe "bundle gem" do
 
       it "builds exe skeleton" do
         expect(bundled_app("#{gem_name}/exe/#{gem_name}")).to exist
+        unless Gem.win_platform?
+          expect(bundled_app("#{gem_name}/exe/#{gem_name}")).to be_executable
+        end
       end
 
       it "requires the main file" do
@@ -729,6 +761,30 @@ RSpec.describe "bundle gem" do
       end
     end
 
+    context "init_gems_rb setting to true" do
+      before do
+        bundle "config set init_gems_rb true"
+        bundle "gem #{gem_name}"
+      end
+
+      it "generates gems.rb instead of Gemfile" do
+        expect(bundled_app("#{gem_name}/gems.rb")).to exist
+        expect(bundled_app("#{gem_name}/Gemfile")).to_not exist
+      end
+    end
+
+    context "init_gems_rb setting to false" do
+      before do
+        bundle "config set init_gems_rb false"
+        bundle "gem #{gem_name}"
+      end
+
+      it "generates Gemfile instead of gems.rb" do
+        expect(bundled_app("#{gem_name}/gems.rb")).to_not exist
+        expect(bundled_app("#{gem_name}/Gemfile")).to exist
+      end
+    end
+
     context "gem.test setting set to rspec" do
       before do
         bundle "config set gem.test rspec"
@@ -844,6 +900,17 @@ RSpec.describe "bundle gem" do
       end
     end
 
+    context "--test parameter set to an invalid value" do
+      before do
+        bundle "gem #{gem_name} --test=foo", raise_on_error: false
+      end
+
+      it "fails loudly" do
+        expect(last_command).to be_failure
+        expect(err).to match(/Expected '--test' to be one of .*; got foo/)
+      end
+    end
+
     context "gem.test setting set to test-unit" do
       before do
         bundle "config set gem.test test-unit"
@@ -870,7 +937,7 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.test set to rspec and --test with no arguments", :hint_text do
+    context "gem.test set to rspec and --test with no arguments" do
       before do
         bundle "config set gem.test rspec"
         bundle "gem #{gem_name} --test"
@@ -887,10 +954,12 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.test setting set to false and --test with no arguments", :hint_text do
+    context "gem.test setting set to false and --test with no arguments", :readline do
       before do
         bundle "config set gem.test false"
-        bundle "gem #{gem_name} --test"
+        bundle "gem #{gem_name} --test" do |input, _, _|
+          input.puts
+        end
       end
 
       it "asks to generate test files" do
@@ -904,9 +973,12 @@ RSpec.describe "bundle gem" do
       it_behaves_like "test framework is absent"
     end
 
-    context "gem.test setting not set and --test with no arguments", :hint_text do
+    context "gem.test setting not set and --test with no arguments", :readline do
       before do
-        bundle "gem #{gem_name} --test"
+        global_config "BUNDLE_GEM__TEST" => nil
+        bundle "gem #{gem_name} --test" do |input, _, _|
+          input.puts
+        end
       end
 
       it "asks to generate test files" do
@@ -922,6 +994,15 @@ RSpec.describe "bundle gem" do
       it_behaves_like "test framework is absent"
     end
 
+    context "gem.test setting set to a test framework and --no-test" do
+      before do
+        bundle "config set gem.test rspec"
+        bundle "gem #{gem_name} --no-test"
+      end
+
+      it_behaves_like "test framework is absent"
+    end
+
     context "--ci with no argument" do
       it "does not generate any CI config" do
         bundle "gem #{gem_name}"
@@ -932,24 +1013,6 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "--ci set to travis" do
-      it "generates a GitHub Actions config file" do
-        bundle "gem #{gem_name} --ci=travis", raise_on_error: false
-        expect(err).to include("Support for Travis CI was removed from gem skeleton generator.")
-
-        expect(bundled_app("#{gem_name}/.travis.yml")).to_not exist
-      end
-    end
-
-    context "--ci set to travis" do
-      it "generates a GitHub Actions config file" do
-        bundle "gem #{gem_name} --ci=travis", raise_on_error: false
-        expect(err).to include("Support for Travis CI was removed from gem skeleton generator.")
-
-        expect(bundled_app("#{gem_name}/.travis.yml")).to_not exist
-      end
-    end
-
     context "--ci set to github" do
       it "generates a GitHub Actions config file" do
         bundle "gem #{gem_name} --ci=github"
@@ -992,6 +1055,17 @@ RSpec.describe "bundle gem" do
       end
     end
 
+    context "--ci set to an invalid value" do
+      before do
+        bundle "gem #{gem_name} --ci=foo", raise_on_error: false
+      end
+
+      it "fails loudly" do
+        expect(last_command).to be_failure
+        expect(err).to match(/Expected '--ci' to be one of .*; got foo/)
+      end
+    end
+
     context "gem.ci setting set to none" do
       it "doesn't generate any CI config" do
         expect(bundled_app("#{gem_name}/.github/workflows/main.yml")).to_not exist
@@ -1000,18 +1074,6 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.ci setting set to travis" do
-      it "errors with friendly message" do
-        bundle "config set gem.ci travis"
-        bundle "gem #{gem_name}", raise_on_error: false
-
-        expect(err).to include("Support for Travis CI was removed from gem skeleton generator,")
-        expect(err).to include("bundle config unset gem.ci")
-
-        expect(bundled_app("#{gem_name}/.travis.yml")).to_not exist
-      end
-    end
-
     context "gem.ci setting set to github" do
       it "generates a GitHub Actions config file" do
         bundle "config set gem.ci github"
@@ -1039,7 +1101,7 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.ci set to github and --ci with no arguments", :hint_text do
+    context "gem.ci set to github and --ci with no arguments" do
       before do
         bundle "config set gem.ci github"
         bundle "gem #{gem_name} --ci"
@@ -1054,10 +1116,12 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.ci setting set to false and --ci with no arguments", :hint_text do
+    context "gem.ci setting set to false and --ci with no arguments", :readline do
       before do
         bundle "config set gem.ci false"
-        bundle "gem #{gem_name} --ci"
+        bundle "gem #{gem_name} --ci" do |input, _, _|
+          input.puts "github"
+        end
       end
 
       it "asks to setup CI" do
@@ -1069,9 +1133,12 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.ci setting not set and --ci with no arguments", :hint_text do
+    context "gem.ci setting not set and --ci with no arguments", :readline do
       before do
-        bundle "gem #{gem_name} --ci"
+        global_config "BUNDLE_GEM__CI" => nil
+        bundle "gem #{gem_name} --ci" do |input, _, _|
+          input.puts "github"
+        end
       end
 
       it "asks to setup CI" do
@@ -1085,6 +1152,19 @@ RSpec.describe "bundle gem" do
       end
     end
 
+    context "gem.ci setting set to a CI service and --no-ci" do
+      before do
+        bundle "config set gem.ci github"
+        bundle "gem #{gem_name} --no-ci"
+      end
+
+      it "does not generate any CI config" do
+        expect(bundled_app("#{gem_name}/.github/workflows/main.yml")).to_not exist
+        expect(bundled_app("#{gem_name}/.gitlab-ci.yml")).to_not exist
+        expect(bundled_app("#{gem_name}/.circleci/config.yml")).to_not exist
+      end
+    end
+
     context "--linter with no argument" do
       it "does not generate any linter config" do
         bundle "gem #{gem_name}"
@@ -1112,6 +1192,17 @@ RSpec.describe "bundle gem" do
       end
     end
 
+    context "--linter set to an invalid value" do
+      before do
+        bundle "gem #{gem_name} --linter=foo", raise_on_error: false
+      end
+
+      it "fails loudly" do
+        expect(last_command).to be_failure
+        expect(err).to match(/Expected '--linter' to be one of .*; got foo/)
+      end
+    end
+
     context "gem.linter setting set to none" do
       it "doesn't generate any linter config" do
         bundle "gem #{gem_name}"
@@ -1141,6 +1232,7 @@ RSpec.describe "bundle gem" do
 
     context "gem.rubocop setting set to true", bundler: "< 3" do
       before do
+        global_config "BUNDLE_GEM__LINTER" => nil
         bundle "config set gem.rubocop true"
         bundle "gem #{gem_name}"
       end
@@ -1160,7 +1252,7 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.linter set to rubocop and --linter with no arguments", :hint_text do
+    context "gem.linter set to rubocop and --linter with no arguments" do
       before do
         bundle "config set gem.linter rubocop"
         bundle "gem #{gem_name} --linter"
@@ -1175,10 +1267,12 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.linter setting set to false and --linter with no arguments", :hint_text do
+    context "gem.linter setting set to false and --linter with no arguments", :readline do
       before do
         bundle "config set gem.linter false"
-        bundle "gem #{gem_name} --linter"
+        bundle "gem #{gem_name} --linter" do |input, _, _|
+          input.puts "rubocop"
+        end
       end
 
       it "asks to setup a linter" do
@@ -1190,9 +1284,12 @@ RSpec.describe "bundle gem" do
       end
     end
 
-    context "gem.linter setting not set and --linter with no arguments", :hint_text do
+    context "gem.linter setting not set and --linter with no arguments", :readline do
       before do
-        bundle "gem #{gem_name} --linter"
+        global_config "BUNDLE_GEM__LINTER" => nil
+        bundle "gem #{gem_name} --linter" do |input, _, _|
+          input.puts "rubocop"
+        end
       end
 
       it "asks to setup a linter" do
@@ -1206,6 +1303,18 @@ RSpec.describe "bundle gem" do
       end
     end
 
+    context "gem.linter setting set to a linter and --no-linter" do
+      before do
+        bundle "config set gem.linter rubocop"
+        bundle "gem #{gem_name} --no-linter"
+      end
+
+      it "does not generate any linter config" do
+        expect(bundled_app("#{gem_name}/.rubocop.yml")).to_not exist
+        expect(bundled_app("#{gem_name}/.standard.yml")).to_not exist
+      end
+    end
+
     context "--edit option" do
       it "opens the generated gemspec in the user's text editor" do
         output = bundle "gem #{gem_name} --edit=echo"
@@ -1215,7 +1324,7 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  context "testing --mit and --coc options against bundle config settings", :readline do
+  context "testing --mit and --coc options against bundle config settings" do
     let(:gem_name) { "test-gem" }
 
     let(:require_path) { "test/gem" }
@@ -1258,7 +1367,7 @@ RSpec.describe "bundle gem" do
       end
       it_behaves_like "--linter=rubocop flag"
       it_behaves_like "--linter=standard flag"
-      it_behaves_like "--linter=none flag"
+      it_behaves_like "--no-linter flag"
       it_behaves_like "--rubocop flag"
       it_behaves_like "--no-rubocop flag"
     end
@@ -1269,7 +1378,7 @@ RSpec.describe "bundle gem" do
       end
       it_behaves_like "--linter=rubocop flag"
       it_behaves_like "--linter=standard flag"
-      it_behaves_like "--linter=none flag"
+      it_behaves_like "--no-linter flag"
       it_behaves_like "--rubocop flag"
       it_behaves_like "--no-rubocop flag"
     end
@@ -1280,7 +1389,7 @@ RSpec.describe "bundle gem" do
       end
       it_behaves_like "--linter=rubocop flag"
       it_behaves_like "--linter=standard flag"
-      it_behaves_like "--linter=none flag"
+      it_behaves_like "--no-linter flag"
     end
 
     context "with linter option in bundle config settings set to standard" do
@@ -1289,7 +1398,7 @@ RSpec.describe "bundle gem" do
       end
       it_behaves_like "--linter=rubocop flag"
       it_behaves_like "--linter=standard flag"
-      it_behaves_like "--linter=none flag"
+      it_behaves_like "--no-linter flag"
     end
 
     context "with linter option in bundle config settings set to false" do
@@ -1298,7 +1407,7 @@ RSpec.describe "bundle gem" do
       end
       it_behaves_like "--linter=rubocop flag"
       it_behaves_like "--linter=standard flag"
-      it_behaves_like "--linter=none flag"
+      it_behaves_like "--no-linter flag"
     end
 
     context "with changelog option in bundle config settings set to true" do
@@ -1318,10 +1427,10 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  context "testing --github-username option against git and bundle config settings", :readline do
+  context "testing --github-username option against git and bundle config settings" do
     context "without git config set" do
       before do
-        sys_exec("git config --global --unset github.user")
+        git("config --global --unset github.user")
       end
       context "with github-username option in bundle config settings set to some value" do
         before do
@@ -1355,10 +1464,10 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  context "testing github_username bundle config against git config settings", :readline do
+  context "testing github_username bundle config against git config settings" do
     context "without git config set" do
       before do
-        sys_exec("git config --global --unset github.user")
+        git("config --global --unset github.user")
       end
 
       it_behaves_like "github_username configuration"
@@ -1369,7 +1478,7 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  context "gem naming with underscore", :readline do
+  context "gem naming with underscore" do
     let(:gem_name) { "test_gem" }
 
     let(:require_path) { "test_gem" }
@@ -1428,7 +1537,7 @@ RSpec.describe "bundle gem" do
       it "includes rake-compiler, but no Rust related changes" do
         expect(bundled_app("#{gem_name}/Gemfile").read).to include('gem "rake-compiler"')
 
-        expect(bundled_app("#{gem_name}/Gemfile").read).to_not include('gem "rb_sys"')
+        expect(bundled_app("#{gem_name}/#{gem_name}.gemspec").read).to_not include('spec.add_dependency "rb_sys"')
         expect(bundled_app("#{gem_name}/#{gem_name}.gemspec").read).to_not include('spec.required_rubygems_version = ">= ')
       end
 
@@ -1488,7 +1597,7 @@ RSpec.describe "bundle gem" do
 
       it "includes rake-compiler, rb_sys gems and required_rubygems_version constraint" do
         expect(bundled_app("#{gem_name}/Gemfile").read).to include('gem "rake-compiler"')
-        expect(bundled_app("#{gem_name}/Gemfile").read).to include('gem "rb_sys"')
+        expect(bundled_app("#{gem_name}/#{gem_name}.gemspec").read).to include('spec.add_dependency "rb_sys"')
         expect(bundled_app("#{gem_name}/#{gem_name}.gemspec").read).to include('spec.required_rubygems_version = ">= ')
       end
 
@@ -1515,7 +1624,7 @@ RSpec.describe "bundle gem" do
     end
   end
 
-  context "gem naming with dashed", :readline do
+  context "gem naming with dashed" do
     let(:gem_name) { "test-gem" }
 
     let(:require_path) { "test/gem" }
@@ -1536,7 +1645,7 @@ RSpec.describe "bundle gem" do
   end
 
   describe "uncommon gem names" do
-    it "can deal with two dashes", :readline do
+    it "can deal with two dashes" do
       bundle "gem a--a"
 
       expect(bundled_app("a--a/a--a.gemspec")).to exist
@@ -1566,7 +1675,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
   end
 
-  describe "#ensure_safe_gem_name", :readline do
+  describe "#ensure_safe_gem_name" do
     before do
       bundle "gem #{subject}", raise_on_error: false
     end
@@ -1594,7 +1703,7 @@ Usage: "bundle gem NAME [OPTIONS]"
 
   context "on first run", :readline do
     it "asks about test framework" do
-      global_config "BUNDLE_GEM__MIT" => "false", "BUNDLE_GEM__COC" => "false"
+      global_config "BUNDLE_GEM__TEST" => nil
 
       bundle "gem foobar" do |input, _, _|
         input.puts "rspec"
@@ -1617,7 +1726,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
 
     it "asks about CI service" do
-      global_config "BUNDLE_GEM__TEST" => "false", "BUNDLE_GEM__MIT" => "false", "BUNDLE_GEM__COC" => "false", "BUNDLE_GEM__LINTER" => "false"
+      global_config "BUNDLE_GEM__CI" => nil
 
       bundle "gem foobar" do |input, _, _|
         input.puts "github"
@@ -1627,7 +1736,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
 
     it "asks about MIT license" do
-      global_config "BUNDLE_GEM__TEST" => "false", "BUNDLE_GEM__COC" => "false", "BUNDLE_GEM__CI" => "false", "BUNDLE_GEM__LINTER" => "false"
+      global_config "BUNDLE_GEM__MIT" => nil
 
       bundle "config list"
 
@@ -1639,7 +1748,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
 
     it "asks about CoC" do
-      global_config "BUNDLE_GEM__MIT" => "false", "BUNDLE_GEM__TEST" => "false", "BUNDLE_GEM__CI" => "false", "BUNDLE_GEM__LINTER" => "false"
+      global_config "BUNDLE_GEM__COC" => nil
 
       bundle "gem foobar" do |input, _, _|
         input.puts "yes"
@@ -1649,8 +1758,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
 
     it "asks about CHANGELOG" do
-      global_config "BUNDLE_GEM__MIT" => "false", "BUNDLE_GEM__TEST" => "false", "BUNDLE_GEM__CI" => "false", "BUNDLE_GEM__LINTER" => "false",
-                    "BUNDLE_GEM__COC" => "false"
+      global_config "BUNDLE_GEM__CHANGELOG" => nil
 
       bundle "gem foobar" do |input, _, _|
         input.puts "yes"
@@ -1660,7 +1768,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
   end
 
-  context "on conflicts with a previously created file", :readline do
+  context "on conflicts with a previously created file" do
     it "should fail gracefully" do
       FileUtils.touch(bundled_app("conflict-foobar"))
       bundle "gem conflict-foobar", raise_on_error: false
@@ -1669,7 +1777,7 @@ Usage: "bundle gem NAME [OPTIONS]"
     end
   end
 
-  context "on conflicts with a previously created directory", :readline do
+  context "on conflicts with a previously created directory" do
     it "should succeed" do
       FileUtils.mkdir_p(bundled_app("conflict-foobar/Gemfile"))
       bundle "gem conflict-foobar"
